FontWeight

Struct FontWeight 

pub struct FontWeight(/* private fields */);
Visual weight class of a font, typically on a scale from 1.0 to 1000.0.

The default value is FontWeight::NORMAL or 400.0.

In variable fonts, this can be controlled with the wght axis. This is an f32 so that it can represent the same range of values as the wght axis.

See https://fonts.google.com/knowledge/glossary/weight

In CSS, this corresponds to the font-weight property.

Implementations



impl FontWeight

pub const THIN: FontWeight

Weight value of 100.

pub const EXTRA_LIGHT: FontWeight

Weight value of 200.

pub const LIGHT: FontWeight

Weight value of 300.

pub const SEMI_LIGHT: FontWeight

Weight value of 350.

pub const NORMAL: FontWeight

Weight value of 400. This is the default value.

pub const MEDIUM: FontWeight

Weight value of 500.

pub const SEMI_BOLD: FontWeight

Weight value of 600.

pub const BOLD: FontWeight

Weight value of 700.

pub const EXTRA_BOLD: FontWeight

Weight value of 800.

pub const BLACK: FontWeight

Weight value of 900.

pub const EXTRA_BLACK: FontWeight

Weight value of 950.



impl FontWeight

pub fn new(weight: f32) -> FontWeight

Creates a new weight attribute with the given value.

pub fn value(self) -> f32

Returns the underlying weight value.

pub fn parse(s: &str) -> Option<FontWeight>

Parses a CSS style font weight attribute.

Examples
assert_eq!(FontWeight::parse("normal"), Some(FontWeight::NORMAL));
assert_eq!(FontWeight::parse("bold"), Some(FontWeight::BOLD));
assert_eq!(FontWeight::parse("850"), Some(FontWeight::new(850.0)));
assert_eq!(FontWeight::parse("invalid"), None);


impl FontWeight

pub fn from_fontconfig(weight: i32) -> FontWeight

Creates a new weight attribute with the given value from Fontconfig.

The values are determined based on the fonts.conf documentation.