pub struct HitPoint {
pub line: usize,
pub index: usize,
pub is_inside: bool,
pub affinity: Affinity,
}Fields
line: usizeText line the cursor is on
index: usizeFirst-byte-index of glyph at cursor (will insert behind this glyph)
is_inside: boolWhether or not the point was inside the bounds of the layout object.
A click outside the layout object will still resolve to a position in the text; for instance a click to the right edge of a line will resolve to the end of that line, and a click below the last line will resolve to a position in that line.
affinity: AffinityAuto Trait Implementations
impl Freeze for HitPoint
impl RefUnwindSafe for HitPoint
impl Send for HitPoint
impl Sync for HitPoint
impl Unpin for HitPoint
impl UnsafeUnpin for HitPoint
impl UnwindSafe for HitPoint