Enum FontStyle
pub enum FontStyle {
Normal,
Italic,
Oblique(Option<f32>),
}Expand description
Visual style or ‘slope’ of a font.
The default value is FontStyle::Normal.
In variable fonts, this can be controlled with the ital
and slnt axes for italic and oblique styles, respectively.
This uses an f32 for the Oblique variant so so that it
can represent the same range of values as the slnt axis.
See https://fonts.google.com/knowledge/glossary/style
In CSS, this corresponds to the font-style property.
Variants
Normal
An upright or “roman” style.
Italic
Generally a slanted style, originally based on semi-cursive forms. This often has a different structure from the normal style.
Oblique(Option<f32>)
Oblique (or slanted) style with an optional angle in degrees, counter-clockwise from the vertical.
Implementations
impl FontStyle
impl FontStyle
pub fn from_fontconfig(slant: i32) -> FontStyle
pub fn from_fontconfig(slant: i32) -> FontStyle
Creates a new style attribute with the given value from Fontconfig.
The values are determined based on the fonts.conf documentation.